<!DOCTYPE TS><TS>
<context>
    <name>AddClock</name>
    <message>
        <source>Add Log Clock</source>
        <translation>Añadir Torta </translation>
    </message>
    <message>
        <source>&amp;New Clock Name:</source>
        <translation>&amp;Nombre de la Torta:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>AddEvent</name>
    <message>
        <source>Add Log Event</source>
        <translation>Añadir Evento</translation>
    </message>
    <message>
        <source>&amp;New Event Name:</source>
        <translation>&amp;Nombre del Evento:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>ClockListView</name>
    <message>
        <source>Edit Event</source>
        <translation>Editar Evento</translation>
    </message>
</context>
<context>
    <name>EditClock</name>
    <message>
        <source>Edit Clock:</source>
        <translation>Editar Torta:</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation>Código:</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <source>Event</source>
        <translation>Evento</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Count</source>
        <translation>Cuenta</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Guardar
&amp;como</translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation>Lista de
&amp;Servicios</translation>
    </message>
    <message>
        <source>Colo&amp;r</source>
        <translation>Colo&amp;r</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation>¿Realmente desea
eliminar</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Eliminar Evento</translation>
    </message>
    <message>
        <source>Clock Modified</source>
        <translation>Cambios almacenados</translation>
    </message>
    <message>
        <source>The clock has been modified.
Do you want to save?</source>
        <translation>Se han hecho modificaciones.
¿Desea guardarlas?</translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation>Ya existe una torta</translation>
    </message>
    <message>
        <source>Clock already exists!  Overwrite?</source>
        <translation>Ya existe una torta con ese nombre.  ¿Sobreescribir?</translation>
    </message>
    <message>
        <source>--- End of clock ---</source>
        <translation>--- Fin de la torta ---</translation>
    </message>
    <message>
        <source>Invalid Code</source>
        <translation>Código inválido</translation>
    </message>
    <message>
        <source>You must provide a clock code!</source>
        <translation>¡Debe indicar un código para la torta!</translation>
    </message>
    <message>
        <source>Duplicate Code</source>
        <translation>Código duplicado</translation>
    </message>
    <message>
        <source>That code is already in use!</source>
        <translation>¡Ese código ya está en uso!</translation>
    </message>
    <message>
        <source>Code Exists</source>
        <translation>El código ya existe</translation>
    </message>
    <message>
        <source>The clock code is already in use!</source>
        <translation>¡El código para la torta ya está en uso!</translation>
    </message>
    <message>
        <source>Missing Clock Code</source>
        <translation>Falta el código</translation>
    </message>
    <message>
        <source>You must specify a clock code!</source>
        <translation>¡Debe suministrar un código para la torta horaria!</translation>
    </message>
    <message>
        <source>Scheduler
Rules</source>
        <translation>Reglas de
horario</translation>
    </message>
    <message>
        <source>Remarks</source>
        <translation>Comentarios</translation>
    </message>
</context>
<context>
    <name>EditEvent</name>
    <message>
        <source>Editing Event</source>
        <translation>Editar Evento</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Audio Only</source>
        <translation>Sólo Audios</translation>
    </message>
    <message>
        <source>Macros Only</source>
        <translation>Sólo Macros</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>CARTUCHO</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPO</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DURACIÓN</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TÍTULO</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>ARTISTA</translation>
    </message>
    <message>
        <source>START</source>
        <translation>INICIO</translation>
    </message>
    <message>
        <source>END</source>
        <translation>FIN</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TIPO</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>TODO</translation>
    </message>
    <message>
        <source>PRE-POSITION LOG</source>
        <translation>LISTA PRE-POSICIÓN</translation>
    </message>
    <message>
        <source>Cue to this event</source>
        <translation>Señalar este evento</translation>
    </message>
    <message>
        <source>before scheduled start.  (First cart will have a STOP transition.)</source>
        <translation>antes de su inicio programado  (el 1er cartucho tendrá transición PARAR)</translation>
    </message>
    <message>
        <source>TIMED START</source>
        <translation>INICIO PROGRAMADO</translation>
    </message>
    <message>
        <source>Use hard start time</source>
        <translation>Usar inicio forzado</translation>
    </message>
    <message>
        <source>Make Post Point</source>
        <translation>Hacer Post Point</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Acción si hay algún evento sonando</translation>
    </message>
    <message>
        <source>Start immediately</source>
        <translation>Iniciar de inmediato</translation>
    </message>
    <message>
        <source>Make next</source>
        <translation>Hacer siguiente</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Espera hasta</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Segue</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Transition if previous event ends before start time:</source>
        <translation>Transición si evento termina antes que éste inicie:</translation>
    </message>
    <message>
        <source>ENFORCING LENGTH</source>
        <translation>FORZAR DURACIÓN</translation>
    </message>
    <message>
        <source>Use AutoFill</source>
        <translation>Usar Autofill</translation>
    </message>
    <message>
        <source>Use Timescaling</source>
        <translation>Usar Timescaling</translation>
    </message>
    <message>
        <source>TRANSITION</source>
        <translation>TRANSICIÓN</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation>CUENTA</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>From Traffic</source>
        <translation>De Tráfico</translation>
    </message>
    <message>
        <source>From Music</source>
        <translation>De Música</translation>
    </message>
    <message>
        <source>Import carts scheduled</source>
        <translation>Importar carts programados</translation>
    </message>
    <message>
        <source>prior to the start of this event.</source>
        <translation>antes del inicio de este evento.</translation>
    </message>
    <message>
        <source>after the end of this event.</source>
        <translation>después del fin del evento.</translation>
    </message>
    <message>
        <source>First cart has a</source>
        <translation>Transic 1er cart</translation>
    </message>
    <message>
        <source>Imported carts have a</source>
        <translation>Transic. cart. importados</translation>
    </message>
    <message>
        <source>transition.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>POST-IMPORT CARTS</source>
        <translation>CARTUCHOS AL TERMINAR</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Guardar &amp;como</translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation>Lista de
&amp;Servicios</translation>
    </message>
    <message>
        <source>C&amp;olor</source>
        <translation>C&amp;olor</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Editar Evento</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation>Macro</translation>
    </message>
    <message>
        <source>Cue</source>
        <translation>Cue</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SEGUE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>PARAR</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>REPROD</translation>
    </message>
    <message>
        <source>, Timed(Start)</source>
        <translation>, Tiempo(Inicio)</translation>
    </message>
    <message>
        <source>, Timed(MakeNext)</source>
        <translation>, Tiempo(HacerSiguiente)</translation>
    </message>
    <message>
        <source>Timed(Wait</source>
        <translation>Tiempo(Esperar</translation>
    </message>
    <message>
        <source>, Post</source>
        <translation>, Post</translation>
    </message>
    <message>
        <source>, Fill</source>
        <translation>, Llenar</translation>
    </message>
    <message>
        <source>, Scale</source>
        <translation>, Escalar</translation>
    </message>
    <message>
        <source>, Traffic</source>
        <translation>, Tráfico</translation>
    </message>
    <message>
        <source>, Music</source>
        <translation>, Música</translation>
    </message>
    <message>
        <source>Event already exists!
Do you want to overwrite it?</source>
        <translation>¡El evento ya exista!
¿Quiere sobreescribirlo?</translation>
    </message>
    <message>
        <source>Warn if fill is over or under</source>
        <translation>Advertir si relleno está encima o debajo </translation>
    </message>
    <message>
        <source>by at least</source>
        <translation>por al menos</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[ninguno]</translation>
    </message>
    <message>
        <source>event.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Import inline traffic with the</source>
        <translation>Importar tráfico con el evento</translation>
    </message>
    <message>
        <source>, Inline Traffic</source>
        <translation>, tráfico en línea</translation>
    </message>
    <message>
        <source>Select from:</source>
        <translation>Elegir desde:</translation>
    </message>
    <message>
        <source>Title Separation</source>
        <translation>Separar títulos</translation>
    </message>
    <message>
        <source>Must have code</source>
        <translation>Con el código</translation>
    </message>
    <message>
        <source>, Scheduler</source>
        <translation>, Programador</translation>
    </message>
    <message>
        <source>REMARKS</source>
        <translation>COMENTARIOS</translation>
    </message>
    <message>
        <source>Len:</source>
        <translation>Long:</translation>
    </message>
    <message>
        <source>PRE-IMPORT CARTS</source>
        <translation>PRE-IMPORTAR CARTUCHOS</translation>
    </message>
    <message>
        <source>IMPORT</source>
        <translation>IMPORTAR</translation>
    </message>
</context>
<context>
    <name>EditEventLine</name>
    <message>
        <source>Edit Event Assignment</source>
        <translation>Editar Asignación de Evento</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>Evento:</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Elegir</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Hora Inicio:</translation>
    </message>
    <message>
        <source>End Time:</source>
        <translation>Hora de Fin:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Invalid Event</source>
        <translation>Evento inválido</translation>
    </message>
    <message>
        <source>The event end time cannot be earlier than the start time.</source>
        <translation>La hora de finalización no puede ser menor a la hora de inicio.</translation>
    </message>
    <message>
        <source>No Such Event</source>
        <translation>No existe el evento</translation>
    </message>
    <message>
        <source>There is no such event.</source>
        <translation>El evento especificado no existe.</translation>
    </message>
    <message>
        <source>This event overlaps with an
already existing event.</source>
        <translation>Este evento se superpone con
un evento ya existente.</translation>
    </message>
</context>
<context>
    <name>EditGrid</name>
    <message>
        <source>Edit Grid:</source>
        <translation>Editar Parrilla:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Edit Clock</source>
        <translation>Editar Torta</translation>
    </message>
    <message>
        <source>Clear Hour</source>
        <translation>Limpiar tortas</translation>
    </message>
    <message>
        <source>Change
&amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Clocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to update ALL clocks in the grid?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This operation cannot be undone!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditNote</name>
    <message>
        <source>Edit Log Note</source>
        <translation>Editar nota de la lista</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>EditPerms</name>
    <message>
        <source>Service Associations</source>
        <translation>Asociaciones de Servicios</translation>
    </message>
    <message>
        <source>Available Services</source>
        <translation>Servicios Disponibles</translation>
    </message>
    <message>
        <source>Enabled Services</source>
        <translation>Servicios Activos</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>EditSchedRules</name>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>CODE</source>
        <translation>CÓDIGO</translation>
    </message>
    <message>
        <source>MAX. IN A ROW</source>
        <translation>MAX EN UNA FILA</translation>
    </message>
    <message>
        <source>MIN. WAIT</source>
        <translation>MIN. ESPERA</translation>
    </message>
    <message>
        <source>DO NOT SCHEDULE AFTER</source>
        <translation>NO PROGRAMAR DESPUÉS</translation>
    </message>
    <message>
        <source>OR AFTER</source>
        <translation>O DESPUÉS</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>DESCRIPCIÓN</translation>
    </message>
    <message>
        <source>Scheduler Codes:</source>
        <translation>Códigos para programación:</translation>
    </message>
    <message>
        <source>Rules Modified</source>
        <translation>Reglas modificadas</translation>
    </message>
    <message>
        <source>The rules have been modified.
Do you want to save?</source>
        <translation>Las reglas han sido modificadas.
¿Desea guardarlas?</translation>
    </message>
    <message>
        <source>Scheduler Rules</source>
        <translation>Reglas de Horario</translation>
    </message>
    <message>
        <source>Artist Separation:</source>
        <translation>Separac. p/Artista:</translation>
    </message>
    <message>
        <source>Import Rules from Clock</source>
        <translation>Importar reglas desde Torta</translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation>Editar Marcador de la pista de voz</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>GenerateLog</name>
    <message>
        <source>Generating Log...</source>
        <translation>Generando Lista...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Servicio:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Fecha:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Elegir</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>The log for</source>
        <translation>La lista para</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>La lista ya existe</translation>
    </message>
    <message>
        <source>No Errors</source>
        <translation>No hubo errores</translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation>No se encontraron errores.</translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation>Esto también borrará las</translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation>pistas de voz asociadas a esta lista.
¿Continuar?</translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation>La pista ya existe</translation>
    </message>
    <message>
        <source>&amp;Create New Log</source>
        <translation>&amp;Crear nueva lista</translation>
    </message>
    <message>
        <source>Merge &amp;Music</source>
        <translation>Fusionar &amp;Música</translation>
    </message>
    <message>
        <source>Merge &amp;Traffic</source>
        <translation>Fusionar &amp;Tráfico</translation>
    </message>
    <message>
        <source>already exists.  Recreating it
will remove any merged Music or Traffic events.

Recreate?</source>
        <translation>ya existe.  Al recrearlo
se eliminará cualquier evento de Música o Tráfico fusionados.

¿Recrear?</translation>
    </message>
    <message>
        <source>Music Exists</source>
        <translation>La Música ya existe</translation>
    </message>
    <message>
        <source>Traffic Exists</source>
        <translation>El Tráfico ya existe</translation>
    </message>
    <message>
        <source>already contains merged music and/or traffic data.
Remerging it will remove this data.  Remerge?</source>
        <translation>ya contiene datos de música o tráfico fusionados.
Remezclarlos removerá estos datos.  ¿Remezclar?</translation>
    </message>
    <message>
        <source>already contains merged traffic data.  Remerging it
will remove this data.  Remerge?</source>
        <translation>ya contiene datos de tráfico fusionados.  Remezclarlos
removerá estos datos.  ¿Remezclar?</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Merged</source>
        <translation>Fusionados</translation>
    </message>
    <message>
        <source>Import Data</source>
        <translation>Datos a importar</translation>
    </message>
    <message>
        <source>Generate Log - User: </source>
        <translation>Generar lista - Usuario: </translation>
    </message>
</context>
<context>
    <name>ImportListView</name>
    <message>
        <source>Insert Log Note</source>
        <translation>Insertar nota de la lista</translation>
    </message>
    <message>
        <source>Edit Log Note</source>
        <translation>Editar nota de la lista</translation>
    </message>
    <message>
        <source>Set PLAY Transition</source>
        <translation>Asignar transición REPROD</translation>
    </message>
    <message>
        <source>Set SEGUE Transition</source>
        <translation>Asignar transición SEGUE</translation>
    </message>
    <message>
        <source>Set STOP Transition</source>
        <translation>Asignar transición PARAR</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Marcador</translation>
    </message>
    <message>
        <source>[Log Note]</source>
        <translation>[Nota de lista]</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>REPROD</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SEGUE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>PARAR</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Pista</translation>
    </message>
    <message>
        <source>[Voice Track]</source>
        <translation>[Pista de voz]</translation>
    </message>
    <message>
        <source>Insert Voice Track</source>
        <translation>Insertar pista de voz</translation>
    </message>
    <message>
        <source>Edit Voice Track</source>
        <translation>Editar pista de voz</translation>
    </message>
</context>
<context>
    <name>ListClocks</name>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Code</source>
        <translation>Código</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Limpiar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>TODO</translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation>Ya existe una torta</translation>
    </message>
    <message>
        <source>An clock with that name already exists!</source>
        <translation>¡Una torta con ese nombre ya existe!</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation>Realmente desea 
eliminar</translation>
    </message>
    <message>
        <source>Delete Clock</source>
        <translation>Eliminar torta</translation>
    </message>
    <message>
        <source>is in use in the following grid(s):</source>
        <translation>está en uso en las siguiente(s) parrilla(s):</translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation>¿Desea eliminarla de cualquier forma?</translation>
    </message>
    <message>
        <source>Clock In Use</source>
        <translation>Torta en uso</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Renombrar</translation>
    </message>
    <message>
        <source>NONE</source>
        <translation>NINGUNA</translation>
    </message>
    <message>
        <source>Log Clocks - User: </source>
        <translation>Tortas - Usuario: </translation>
    </message>
</context>
<context>
    <name>ListEvents</name>
    <message>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>TODO</translation>
    </message>
    <message>
        <source>Event Exists</source>
        <translation>El evento ya existe</translation>
    </message>
    <message>
        <source>An event with that name already exists!</source>
        <translation>¡Un evento con ese nombre ya existe!</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation>Realmente desea
eliminar</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Eliminar Evento</translation>
    </message>
    <message>
        <source>is in use in the following clocks:</source>
        <translation>está en uso en las siguientes tortas:</translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation>¿Aún así desea eliminarla?</translation>
    </message>
    <message>
        <source>Event In Use</source>
        <translation>El evento está en uso</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Renombrar</translation>
    </message>
    <message>
        <source>NONE</source>
        <translation>NINGUNO</translation>
    </message>
    <message>
        <source>Log Events - User: </source>
        <translation>Eventos - Usuario: </translation>
    </message>
</context>
<context>
    <name>ListGrids</name>
    <message>
        <source>Log Grids</source>
        <translation>Parrillas</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Cerrar</translation>
    </message>
</context>
<context>
    <name>ListSvcs</name>
    <message>
        <source>Rivendell Services</source>
        <translation>Servicios Rivendell</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>SERVICIO</translation>
    </message>
    <message>
        <source>OLDEST REPORT</source>
        <translation>REPORTE MAS ANTIGUO</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[ninguno]</translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation>&amp;Purgar datos</translation>
    </message>
    <message>
        <source>&amp;Generate
Reports</source>
        <translation>&amp;Generar 
Reportes</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>No puedo conectarme</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation></translation>
    </message>
    <message>
        <source>Select an operation:</source>
        <translation>Elija una operación:</translation>
    </message>
    <message>
        <source>Edit &amp;Events</source>
        <translation>Editar &amp;Eventos</translation>
    </message>
    <message>
        <source>Edit C&amp;locks</source>
        <translation>Editar &amp;Tortas</translation>
    </message>
    <message>
        <source>Edit G&amp;rids</source>
        <translation>Edtar &amp;Parrillas</translation>
    </message>
    <message>
        <source>&amp;Generate Logs</source>
        <translation>&amp;Generar Listas</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Manage &amp;Reports</source>
        <translation>Admin. &amp;Reportes</translation>
    </message>
    <message>
        <source>RDLogManager - User: </source>
        <translation>RDLogManager - Usuario: </translation>
    </message>
    <message>
        <source>RDLogEdit -- Database Skew</source>
        <translation>RDLOgEdit -- Asimetría en la base de datos</translation>
    </message>
    <message>
        <source>This version of RDLogManager is incompatible with the version installed on the server.
See your system administrator for an update!</source>
        <translation>Esta versión de RDLogManager no es compatible con la versión instalada en el servidor.
¡Solicite al administrador del sistema una actualización!</translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation>Elija las fechas para el reporte</translation>
    </message>
    <message>
        <source>&amp;Report:</source>
        <translation>&amp;Reporte:</translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation>Fecha &amp;Inicio:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Elegir</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation>Fecha &amp;Final:</translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation>&amp;Generar
Reporte</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;errar</translation>
    </message>
    <message>
        <source>Invalid Date Range</source>
        <translation>Rango de fechas inválido</translation>
    </message>
    <message>
        <source>The end date cannot be earlier than the start date!</source>
        <translation>¡La hora de finalización no puede ser menor a la hora de inicio!</translation>
    </message>
    <message>
        <source>This report type cannot span multiple dates!</source>
        <translation>¡Este reporte no puede emitir múltiples fechas!</translation>
    </message>
    <message>
        <source>This report type cannot span multiple months!</source>
        <translation>¡Este reporte no puede emitir múltiples meses!</translation>
    </message>
    <message>
        <source>Report Complete</source>
        <translation>Reporte completado</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="obsolete">¡Reporte completado!</translation>
    </message>
    <message>
        <source>Report generated in</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameItem</name>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Name Conflict</source>
        <translation>Conflicto de nombres</translation>
    </message>
    <message>
        <source>That name already exists!</source>
        <translation>¡Ese nombre ya existe!</translation>
    </message>
</context>
<context>
    <name>SvcRec</name>
    <message>
        <source>Mo</source>
        <translation>Lu</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Ma</translation>
    </message>
    <message>
        <source>We</source>
        <translation>Mi</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>Ju</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Vi</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>Sá</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>Do</translation>
    </message>
</context>
<context>
    <name>SvcRecDialog</name>
    <message>
        <source>Report Data</source>
        <translation>Reporte de datos</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Delete Report Data</source>
        <translation>Borrar Reporte de Datos</translation>
    </message>
    <message>
        <source>Are you sure you want to delete report data for</source>
        <translation>Desea eliminar el reporte de datos para</translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation>&amp;Borrar
Datos</translation>
    </message>
</context>
<context>
    <name>editSchedCodeRules</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation>Código:</translation>
    </message>
    <message>
        <source>Max. in a row:</source>
        <translation>Máx. por fila:</translation>
    </message>
    <message>
        <source>Min. wait:</source>
        <translation>Espera Mín.:</translation>
    </message>
    <message>
        <source>Do not schedule after:</source>
        <translation>No programar después de:</translation>
    </message>
    <message>
        <source>Or after:</source>
        <translation>O después de:</translation>
    </message>
    <message>
        <source>Edit Rules for Code</source>
        <translation>Editar reglas para el código</translation>
    </message>
</context>
</TS>
